@@ -4,8 +4,12 @@ from . import autopackages  # noqa: F401
 from . import ctypes  # noqa: F401
 from . import docutils  # noqa: F401
 from . import ftplib  # noqa: F401
+from . import ipython  # noqa: F401
 from . import lxml  # noqa: F401
 from . import matplotlib  # noqa: F401
+from . import multiprocessing  # noqa: F401
+from . import opencv  # noqa: F401
+from . import platformdirs  # noqa: F401
 from . import pydoc  # noqa: F401
 from . import pyenchant  # noqa: F401
 from . import pygame  # noqa: F401
@@ -13,10 +17,13 @@ from . import pyopengl  # noqa: F401
 from . import pyside  # noqa: F401
 from . import pyside2  # noqa: F401
 from . import qt5  # noqa: F401
+from . import qt6  # noqa: F401
+from . import rtree  # noqa: F401
 from . import setuptools  # noqa: F401
 from . import shiboken2  # noqa: F401
 from . import sip  # noqa: F401
 from . import six  # noqa: F401
+from . import sphinx  # noqa: F401
 from . import sysconfig_module  # noqa: F401
 from . import tkinter  # noqa: F401
 from . import virtualenv  # noqa: F401
