@@ -20,6 +20,9 @@ AUTO_PACKAGES=[
     # XXX: Check if this is still needed.
     'zmq',
 
+    # Swig using packages
+    'sentencepiece',
+
     # Various
     'numpy',
     'scipy',
@@ -32,7 +35,7 @@ def check(cmd, mf):
     for python_package in AUTO_PACKAGES:
         m = mf.findNode(python_package)
         if m is None or m.filename is None:
-            return None
+            continue
 
         to_include.append(python_package)
 
