@@ -1,4 +1,5 @@
 import os
+from pkg_resources import packaging
 
 
 def check(cmd, mf):
@@ -6,6 +7,11 @@ def check(cmd, mf):
     if m is None or m.filename is None:
         return None
 
+    # Don't try to import unless we've found the library,
+    # otherwise we'll get an error when trying to use
+    # py2app on a system with matplotlib
+    from matplotlib import __version__ as VER
+
     if cmd.matplotlib_backends:
         backends = {}
         for backend in cmd.matplotlib_backends:
@@ -22,8 +28,10 @@ def check(cmd, mf):
         backends = {"packages": ["matplotlib"]}
 
     result = {
-        "prescripts": ["py2app.recipes.matplotlib_prescript"],
         "resources": [os.path.join(os.path.dirname(m.filename), "mpl-data")],
     }
+    if packaging.version.parse(VER) < packaging.version.parse('3.1'):
+        result.update({"prescripts": ["py2app.recipes.matplotlib_prescript"]})
+
     result.update(backends)
     return result
